@@ -9,10 +9,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(module_path pod_path);
 
-our $VERSION = '0.13.2'; # VERSION
-our $DATE = '2014-06-22'; # DATE
-
-our $ALT = 'SHARYANTO';
+our $VERSION = '0.01'; # VERSION
 
 my $SEPARATOR;
 
@@ -33,12 +30,18 @@ sub module_path {
     $opts->{find_pm}  //= 1;
     $opts->{find_pmc} //= 1;
     $opts->{find_pod} //= 0;
-    $opts->{find_prefix} //= 0;
 
     require Cwd if $opts->{abs};
 
     my @res;
-    my $add = sub { push @res, $opts->{abs} ? Cwd::abs_path($_[0]) : $_[0] };
+    my $add_res = sub {
+        my $path = shift;
+        if (-f $path) {
+            push @res, $opts->{abs} ? Cwd::abs_path($path) : $path;
+            return 1;
+        }
+        0;
+    };
 
     my $relpath;
 
@@ -50,32 +53,14 @@ sub module_path {
         next if ref($dir);
 
         my $prefix = $dir . $SEPARATOR . $relpath;
-        if ($opts->{find_prefix}) {
-            if (-d $prefix) {
-                $add->($prefix);
-                last unless $opts->{all};
-            }
-        }
         if ($opts->{find_pmc}) {
-            my $file = $prefix . ".pmc";
-            if (-f $file) {
-                $add->($file);
-                last unless $opts->{all};
-            }
+            last if $add_res->($prefix . ".pmc") && !$opts->{all};
         }
         if ($opts->{find_pm}) {
-            my $file = $prefix . ".pm";
-            if (-f $file) {
-                $add->($file);
-                last unless $opts->{all};
-            }
+            last if $add_res->($prefix . ".pm" ) && !$opts->{all};
         }
         if ($opts->{find_pod}) {
-            my $file = $prefix . ".pod";
-            if (-f $file) {
-                $add->($file);
-                last unless $opts->{all};
-            }
+            last if $add_res->($prefix . ".pod") && !$opts->{all};
         }
     }
 
@@ -106,7 +91,7 @@ Module::Path - Get the path to a locally installed module
 
 =head1 VERSION
 
-This document describes version 0.13.2 of Module::Path (from Perl distribution Alt-Module-Path-SHARYANTO), released on 2014-06-22.
+version 0.01
 
 =head1 SYNOPSIS
 
